<?php

namespace Drupal\ik_constant_contact\Plugin\Block;

use Drupal\Core\Block\BlockBase;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a constant contact signup form per list that is enabled.
 *
 * @Block(
 *   id = "ik_constant_contact",
 *   admin_label = @Translation("Constant Contact Signup Form"),
 *   deriver = "Drupal\ik_constant_contact\Plugin\Derivative\ConstantContactBlockDerivative"
 * )
 */
class ConstantContactBlock extends BlockBase implements ContainerFactoryPluginInterface {

  /**
   * Drupal\Core\Form\FormBuilderInterface.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * {@inheritdoc}
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, FormBuilderInterface $form_builder) {
    parent::__construct($configuration, $plugin_id, $plugin_definition);
    $this->formBuilder = $form_builder;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition) {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('form_builder')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);
    $config = $this->getConfiguration();

    $form['first_name'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display First Name field?'),
      '#default_value' => isset($config['first_name']) ? $config['first_name'] : 0,
    ];
    $form['first_name_required'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Require First Name field?'),
      '#default_value' => isset($config['first_name_required']) ? $config['first_name_required'] : 0,
    ];
    $form['last_name'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Display Last Name field?'),
      '#default_value' => isset($config['last_name']) ? $config['last_name'] : 0,
    ];
    $form['last_name_required'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Require Last Name field?'),
      '#default_value' => isset($config['last_name_required']) ? $config['last_name_required'] : 0,
    ];
    $form['body'] = [
      '#type' => 'text_format',
      '#title' => $this->t('Body'),
      '#default_value' => isset($config['body']) ? $config['body']['value'] : NULL,
      '#format' => isset($config['format']) ? $config['body']['format'] : NULL,
    ];
    $form['success_message'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Custom Success Message'),
      '#default_value' => isset($config['success_message']) ? $config['success_message'] : NULL,
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $values = $form_state->getValues();
    $this->configuration['first_name'] = $values['first_name'];
    $this->configuration['first_name_required'] = $values['first_name_required'];
    $this->configuration['last_name'] = $values['last_name'];
    $this->configuration['last_name_required'] = $values['last_name_required'];
    $this->configuration['body'] = $values['body'];
    $this->configuration['success_message'] = $values['success_message'];
  }

  /**
   * {@inheritdoc}
   */
  public function build() {
    $listConfig = $this->getConfiguration();
    $listConfig['list_id'] = str_replace('ik_constant_contact:', '', $this->getPluginId());

    return $this->formBuilder->getForm('Drupal\ik_constant_contact\Form\ConstantContactBlockForm', $listConfig);
  }

}
